==> libzypp_15.3.0.orig.tar.xz: libzypp-15.3.0/zypp/ProvideFilePolicy.h <==
/*---------------------------------------------------------------------\
|                          ____ _   __ __ ___                          |
|                         |__  / \ / / . \ . \                         |
|                           / / \ V /|  _/  _/                         |
|                          / /__ | | | | | |                           |
|                         /_____||_| |_| |_|                           |
|                                                                      |
\---------------------------------------------------------------------*/

#ifndef ZYPP_PROVIDEFILEPOLICY_H
#define ZYPP_PROVIDEFILEPOLICY_H

#include <iosfwd>

#include "zypp/base/Function.h"
#include "zypp/base/Functional.h"

///////////////////////////////////////////////////////////////////
namespace zypp
{ /////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////
// CLASS NAME : ProvideFilePolicy
  
  /** Policy for \ref provideFile.
    * Provides callback hooks for e.g progress reporting or
    * behaviour on checksum failure. Provides default
    * implementations if no callback is set.
    */
  class ProvideFilePolicy
  {
  public:
    /** Progress callback signature. */
    typedef function<bool ( int )> ProgressCB;

    /** Set callback. */
    ProvideFilePolicy & progressCB( ProgressCB progressCB_r )
    { _progressCB = progressCB_r; return *this; }

    /** Evaluate callback. */
    bool progress( int value ) const;

  public:
    /** FailOnChecksumError callback signature. */
    typedef function<bool ()> FailOnChecksumErrorCB;

    /** Set callback. */
    ProvideFilePolicy & failOnChecksumErrorCB( FailOnChecksumErrorCB failOnChecksumErrorCB_r )
    { _failOnChecksumErrorCB = failOnChecksumErrorCB_r; return *this; }

    /** Set callback convenience.
      * Let callback return \c yesno_r.
    */
    ProvideFilePolicy & failOnChecksumErrorCB( bool yesno_r );

    /** Evaluate callback. */
    bool failOnChecksumError() const;

  private:
    FailOnChecksumErrorCB _failOnChecksumErrorCB;
    ProgressCB            _progressCB;
  };

} // namespace zypp
///////////////////////////////////////////////////////////////////
#endif // ZYPP_PROVIDEFILEPOLICY_H

==> libzypp_17.6.1.orig.tar.xz: libzypp-17.6.1/zypp/ProvideFilePolicy.h <==
/*---------------------------------------------------------------------\
|                          ____ _   __ __ ___                          |
|                         |__  / \ / / . \ . \                         |
|                           / / \ V /|  _/  _/                         |
|                          / /__ | | | | | |                           |
|                         /_____||_| |_| |_|                           |
|                                                                      |
\---------------------------------------------------------------------*/

#ifndef ZYPP_PROVIDEFILEPOLICY_H
#define ZYPP_PROVIDEFILEPOLICY_H

#include <iosfwd>

#include "zypp/base/Function.h"
#include "zypp/base/Functional.h"
#include "zypp/FileChecker.h"

///////////////////////////////////////////////////////////////////
namespace zypp
{
  ///////////////////////////////////////////////////////////////////
  /// \class ProvideFilePolicy
  /// \brief Policy for \ref provideFile and \ref RepoMediaAccess.
  ///
  /// Provides callback hook for progress reporting and an optional
  /// \ref FileCecker passed down to the \ref Fetcher.
  ///////////////////////////////////////////////////////////////////
  class ProvideFilePolicy
  {
  public:
    /** Progress callback signature. */
    typedef function<bool ( int )> ProgressCB;

    /** Set callback. */
    ProvideFilePolicy & progressCB( ProgressCB progressCB_r )
    { _progressCB = progressCB_r; return *this; }

    /** Evaluate callback. */
    bool progress( int value ) const;

  public:
    /** Add a \ref FileCecker passed down to the \ref Fetcher */
    ProvideFilePolicy & fileChecker( FileChecker fileChecker_r )
    { _fileChecker = std::move(fileChecker_r); return *this; }

    /** The \ref FileCecker. */
    const FileChecker & fileChecker() const
    { return _fileChecker; }

  private:
    FileChecker           _fileChecker;
    ProgressCB            _progressCB;
  };

} // namespace zypp
///////////////////////////////////////////////////////////////////
#endif // ZYPP_PROVIDEFILEPOLICY_H
